@@ -1,5 +1,5 @@
-from .db import post_request
-
+from .db import post_request,getZipRows
+from abstract_utilities import make_list
 
 def get_data(tableName=None,columnName=None,columnValues=None,**kwargs):
     columnName = make_list(columnName) if columnName else columnName
@@ -19,27 +19,27 @@ def get_all_pairs():
 def get_pair_from_id(pair_id):
     tableName = 'pairs'
     rows = get_data(tableName=tableName,searchColumn='id',columnValues=pair_id)
-    result = getZipRows(tableName=result,rows=rows,schema=schema)
+    result = getZipRows(tableName=tableName,rows=rows,schema=schema)
     return result
 def get_meta_data_from_id(meta_id):
     tableName = 'metadata'
     rows = get_data(tableName=tableName,searchColumn='id',columnValues=meta_id)
-    result = getZipRows(tableName=result,rows=rows,schema=schema)
+    result = getZipRows(tableName=tableName,rows=rows,schema=schema)
     return result
 def get_txns_from_pair_id(pair_id):
     tableName = 'transactions'
     rows = get_data(tableName=tableName,searchColumn='pair_id',columnValues=pair_id)
-    result = getZipRows(tableName=result,rows=rows,schema=schema)
+    result = getZipRows(tableName=tableName,rows=rows,schema=schema)
     return result
 def get_genesis_txn_from_log_id(log_id):
     tableName = 'metadata'
     rows = get_data(tableName=tableName,searchColumn='log_id',columnValues=log_id)
-    result = getZipRows(tableName=result,rows=rows,schema=schema)
+    result = getZipRows(tableName=tableName,rows=rows,schema=schema)
     return result
 def get_meta_data_by_mint(mint):
     tableName = 'pairs'
     rows = get_data(tableName=tableName,searchColumn='mint',columnValues=mint)
-    result = getZipRows(tableName=result,rows=rows,schema=schema)
+    result = getZipRows(tableName=tableName,rows=rows,schema=schema)
     return result
 def get_assigned_account(addresses):
     tableName = 'wallet_account_assignments'
